Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(234)

Unified Diff: ash/wm/ash_focus_rules.cc

Issue 13896026: Stick windows to sides of workspaces (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Dock with zero width (rebase) Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/wm/activation_controller.cc ('k') | ash/wm/default_window_resizer.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/wm/ash_focus_rules.cc
diff --git a/ash/wm/ash_focus_rules.cc b/ash/wm/ash_focus_rules.cc
index 33829993dda95370dcb9767e58e7ea414cc555ee..d24a1f9a3b1774b1abef49528df077b473fd1e6c 100644
--- a/ash/wm/ash_focus_rules.cc
+++ b/ash/wm/ash_focus_rules.cc
@@ -24,9 +24,10 @@ const int kWindowContainerIds[] = {
internal::kShellWindowId_AppListContainer,
internal::kShellWindowId_DefaultContainer,
// Panel, launcher and status are intentionally checked after other
// containers even though these layers are higher. The user expects their
// windows to be focused before these elements.
+ internal::kShellWindowId_DockedContainer,
internal::kShellWindowId_PanelContainer,
internal::kShellWindowId_ShelfContainer,
internal::kShellWindowId_StatusContainer,
@@ -24,9 +24,10 @@ const int kWindowContainerIds[] = {
internal::kShellWindowId_AppListContainer,
internal::kShellWindowId_DefaultContainer,
- // Panel, launcher and status are intentionally checked after other
+ // Docked, panel, launcher and status are intentionally checked after other
// containers even though these layers are higher. The user expects their
// windows to be focused before these elements.
« no previous file with comments | « ash/wm/activation_controller.cc ('k') | ash/wm/default_window_resizer.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698